==> whmcs-8.6.2-release.1.zip: modules/gateways/callback/index.php <==
<?php //ICB0 72:0 81:1044                                                     ?><?php //00cb7
// *************************************************************************
// *                                                                       *
// * WHMCS - The Complete Client Management, Billing & Support Solution    *
// * Copyright (c) WHMCS Ltd. All Rights Reserved,                         *
// * Version:8.6.2 (8.6.2-release.1)                                      *
// * BuildId:b8a9b70.304                                                  *
// * Build Date:14 Jun 2023                                               *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * Email: info@whmcs.com                                                 *
// * Website: http://www.whmcs.com                                         *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * This software is furnished under a license and may be used and copied *
// * only  in  accordance  with  the  terms  of such  license and with the *
// * inclusion of the above copyright notice.  This software  or any other *
// * copies thereof may not be provided or otherwise made available to any *
// * other person.  No title to and  ownership of the  software is  hereby *
// * transferred.                                                          *
// *                                                                       *
// * You may not reverse  engineer, decompile, defeat  license  encryption *
// * mechanisms, or  disassemble this software product or software product *
// * license.  WHMCompleteSolution may terminate this license if you don't *
// * comply with any of the terms and conditions set forth in our end user *
// * license agreement (EULA).  In such event,  licensee  agrees to return *
// * licensor  or destroy  all copies of software  upon termination of the *
// * license.                                                              *
// *                                                                       *
// * Please see the EULA file for the full End User License Agreement.     *
// *                                                                       *
// *************************************************************************
if(extension_loaded('ionCube Loader')){die('The file '.__FILE__." is corrupted.\n");}echo("\nScript error: the ".(($cli=(php_sapi_name()=='cli')) ?'ionCube':'<a href="https://www.ioncube.com">ionCube</a>')." Loader for PHP needs to be installed.\n\nThe ionCube Loader is the industry standard PHP extension for running protected PHP code,\nand can usually be added easily to a PHP installation.\n\nFor Loaders please visit".($cli?":\n\nhttps://get-loader.ioncube.com\n\nFor":' <a href="https://get-loader.ioncube.com">get-loader.ioncube.com</a> and for')." an instructional video please see".($cli?":\n\nhttp://ioncu.be/LV\n\n":' <a href="http://ioncu.be/LV">http://ioncu.be/LV</a> ')."\n\n");exit(199);
?>
HR+cPrRnPF3sN5tu/pX2yTFYJkB7rJfZfwD0Pke2cQFRQoq7ftf7Z0Mpnxv3YGPDvly85QPJjzXR
6QV1Sl7Qcbc5CaDeJTFVYBxk+g+OBvLDsWjgBm/m5BdknCR78Cklh0jblZJZXwvlJ0Si/eg0XAbV
dTWEV5dAZDEKAuRixM7dZ44zSP0zib+JFI3/lra9iLFP5fJO5tLD8473+3EhcSx9KIvwY0hpOzoO
yAcwnY/cspB+w1GT3b64IKM0Pr8IIZ+2KG6ZR9ajss9px3fcfdJCOsEbUr329aoFMPZj5gCNOm91
UW1RHzToEnZB+43N7Djdz2AgQpC+NczV1RjP3ykIYy9THLe0NlgwkAdomu0V8wDTWvtgPfoVWaUU
re+Rl2My46CSOpUijKW6xMAt1dkFwbVIOGhLWTaeVmyZxnibvZCINi6QdpxaHf+dEm9kzqiUsvnw
s6kUrr+WDG4vopi0VI9FDi+LDne0xfDdG+IorDPSPyrpul6vGrDJf6AOC5cw8d7A8NSj+D2PfXaS
3oLeLkyHBgi91FMA7TjOZCYhm6kvxBFSyNpjP2BjQQAKBL8P6S9/TZYPE9BxOp3fC5BTQ1KTDYyD
Vyapivg8kUlPmxKnhlen+nU0+ocfLz9svfDV6jsMWcdOtCtCWAPylTz3yNnJipJ06BFzhdgOTubx
SKJx/ckjOdTJBd20ONw1UFjbBOx872B3ar6AfOPokkGAWkEftHa+xcByvxZtvpvZuwj80yaXGmOd
IhqQjHuxiqKAW/HKnlJqa+DehaFOLP6H7SxbgMBZlZFPeV1ng1QpXj0jeqN4T2D50H+Tut/c2i6I
7fROkGRmfEM2tNlpzNkgmplOVWg0mIGfvvQRQWUeseeF+Z6tvzAdtG===
HR+cPxGWbJq2y6qogvu07jIX1H4/NzvSDBXKShh8W0SUoqQhNFqrVKg2a1U8Amd19M6Tvq/0CxQ4
yG8ggUvzXi32vK6fIEjUd1Xfq4RBWbkn38bfKQ4i/trRLUV/ndsvz558qFvVmOt0ooRdslstpnmk
FbuKVHmTFPtia3IPFOQRSWhmCePsAeBb2c94rYLxGSjWOMgDkGHUAekk6IbGqs+5Hxc4U4Ie0sW6
vEsLugNZZbxeaeu+KAyvgnfoVACzo0uRZ4sSNI0YIOEwrzaXc4dlwCoQWEoXM/VkE7E9gfpMou52
0bkvRauRzeVqqgziewnOW0Op2XWrQ52BJLZQK6ga1/dGxUAv2JJ/RdCuZFoAs5b9P9x/ep3EgGhf
gBeYZ9AUWNJkwSM+WAxiGeFNiYJwX4Lq+rsDM7o1AdhpK7epdtv7HzBZLDF0P6poAOpAj/1GaTmu
QoEle2CCOPbxVfmLihctuSEMqPVLjJ0D2eRYPS6tdhAUDclCqBfT139R1GWCq4JLoQb0zhREzaXB
HkVs8AxpvvOt6P2Xa2Xh4Sb3LOz+4nEcll2iOnkSkhgKuW0tL9/0LGfNMHYtRuHwKHTcKQsgw7AV
qOemU+jB6hPZOBKdQrVUoVpkoi8SR7LiIqNRvyo2sGWCtVVxBQiXoHYOaSmZXEsIBmaKmSqMOJAm
0HzGf6afWR3AUrmmdBkSP5LSJv7l1Bt/lyWmCrckqyvkAgiXcQLHuD+AuXk923rQ/QexqJWdyAAn
u+FiPghuotFQdQlm2GQyjGCiGQHfPbsiug//s+5CZhT57WfV4yAMC1StaOgT7bZuf6ALgX1w2ZCg
VgGi+A6VibTAHOxKE2cZIaZVtGen8Qmf2Uto/D1MNwA1yUjPXcnHmw74rpRu

==> whmcs-8.7.2-release.1.zip: modules/gateways/callback/index.php <==
<?php //ICB0 72:0 81:1044                                                     ?><?php //00cb7
// *************************************************************************
// *                                                                       *
// * WHMCS - The Complete Client Management, Billing & Support Solution    *
// * Copyright (c) WHMCS Ltd. All Rights Reserved,                         *
// * Version:8.7.2 (8.7.2-release.1)                                      *
// * BuildId:5e9b2f1.301                                                  *
// * Build Date:25 Apr 2023                                               *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * Email: info@whmcs.com                                                 *
// * Website: http://www.whmcs.com                                         *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * This software is furnished under a license and may be used and copied *
// * only  in  accordance  with  the  terms  of such  license and with the *
// * inclusion of the above copyright notice.  This software  or any other *
// * copies thereof may not be provided or otherwise made available to any *
// * other person.  No title to and  ownership of the  software is  hereby *
// * transferred.                                                          *
// *                                                                       *
// * You may not reverse  engineer, decompile, defeat  license  encryption *
// * mechanisms, or  disassemble this software product or software product *
// * license.  WHMCompleteSolution may terminate this license if you don't *
// * comply with any of the terms and conditions set forth in our end user *
// * license agreement (EULA).  In such event,  licensee  agrees to return *
// * licensor  or destroy  all copies of software  upon termination of the *
// * license.                                                              *
// *                                                                       *
// * Please see the EULA file for the full End User License Agreement.     *
// *                                                                       *
// *************************************************************************
if(extension_loaded('ionCube Loader')){die('The file '.__FILE__." is corrupted.\n");}echo("\nScript error: the ".(($cli=(php_sapi_name()=='cli')) ?'ionCube':'<a href="https://www.ioncube.com">ionCube</a>')." Loader for PHP needs to be installed.\n\nThe ionCube Loader is the industry standard PHP extension for running protected PHP code,\nand can usually be added easily to a PHP installation.\n\nFor Loaders please visit".($cli?":\n\nhttps://get-loader.ioncube.com\n\nFor":' <a href="https://get-loader.ioncube.com">get-loader.ioncube.com</a> and for')." an instructional video please see".($cli?":\n\nhttp://ioncu.be/LV\n\n":' <a href="http://ioncu.be/LV">http://ioncu.be/LV</a> ')."\n\n");exit(199);
?>
HR+cPpKN16SR/ln8agIHHF+KwEBbww7Hw6T0+zyoPtWBbRJqWdtbYl1yNNOV1dk/fhvmIl9wbokB
6jHM7KR8h2VQbyUEpKbdb0Km466DUZASbTZZgZPutgZBlfL25X/qMfqcP7KMolSO1pLwl2V3DAMU
wjMjfwZ0rDZKv+GWb112YfBou+mKZ4v8G9/syiDJDyQpch4FA9T8OoYxUN7q/FEQ/4xcHUuQlyeg
mAn6YC9hTVIB84TTQV+9oG51cqOFc8XoHvT6sFm0ODvubrng10w/cslrs0VBqSGUlX8KeYaKT9rZ
651KvNNkwmv6OkzBJIKzyuFXtnp/RS+R3TgwEdgEb3KYp7SuDCgs+5fWPSC1JzOPncGRpuDtNmje
eJ1Dp7qThWXvIiupeOM8ecFglAtPmEpdKnf5Dhqt3ef10lcTHfI3xrcGLXc7po3ZgOrDuZr4e4Ba
ZdReugjMZXzjXEeLrTrPwztOPtwQRJc7VeJmbuED75uLUt/E9sj4YN+8LgoFHWsLlv/4SR8uUgQG
LmJITVm7XfzjQpbOwY+S9T80flFtqvyMqIqeKB5ymuorQ3+X+s85bKyiJtc7rCtLSB8KijI31ez3
GG4lj1BKpNinfFoPlqPuMyPOoVbwxRNs5ixa7eZepwgJteKZsPZuxlgbyv/P3LORL646NkDhYfGv
Z+nTBNVhJpvaQLm+K8To6v5Loy+gR2banZg9wO/UnPk7c3YTrAS8mHp2Zx/2+1Fvpf1Ph5MIdHWm
sabI3BXyT3USHasRjdO/p3xYmqRfd26s+HJSo7dMmuEcb3P56cyMJHg5nm3ocEiVhWT4SxyI9dfg
y6n9rZAnXMKL6oMKo1MJQLikLBhb9btrvHUWhWaggxAXoFFTmQ2dqyu/=
HR+cPogX0yEvSlZqD1+Mu8sFipQnbuvolXeXEUDR3NDOGXD2hcJYEPUescsaNa9H0w+x+QAWfUQ4
9C7pBuSHZQRLpjVhL52I0+WFuGqjqwmkj9TIOunovvbDdxEcBCZb0SEpU9u5YNAs6b3/6v/FcwQh
BpFfaSFhl8bidbGllj29bCOFRDBvzjJkImLwC3xX40mZLLstPSnI8A3bij1jlyI7rMFPDpWe9APs
1zAF7ZXBGAphW+PsbBuhBJrrqw+t0PqHKiMXRHUPH3K9qwsibZzDMg29O6e0bcHG2GMJprdbzalc
NrzIKd4dZf1PdhQnFbeeEK2Z9nN/1CcBpsf150Q/7/EgjCuiBwCC1W4E+WaDmPdE72+UOVTOo1AI
Cx1jNFSiHT8K2QrFVX9biJTpyc21xvOwbz4FHr9wbtVzx4BRLYV72bW7BxU0mrgbCQpXmRjnr6c5
o5Ig6ePyOGh7mhIQ8Lz2ONMKHSzOgFtd6bHK/ZvzublFfc9D5xfPKXbvqb0NZ6ZDvIoBoqLCWu7E
+nhD/lV1v4ms/DXN6TwCxTFM+aMrh/FafvkC0qWuGg0kCvsXzHTpxEE5ai82sCZTJwzlYCDUbkfu
AXzOtaKPq4kHtYQJAS2FXu6h+p+Rbc8gT8dg80I7r7lfoTICldJcI3ONmIx9zhs1JninKGWVgTSU
gyfzDrswOiKpKJWD9NFlCcflm+wFAM1AYq6Jc8/7eZTb4uazS268A3iZvSsEQc+UuVKX1mm1NJ/Y
STQx9lPClNAxxheqigsBjqLTSz3YpyFt6uoHws8f7MO2hyLBfoBYauA07Zipcivx2WmjiXmYo/Uw
UiUEg6aYb++6u2QPRdMXTQb86aMNZlh69P1+BT25eAAa8DiPU0O/lQ7FSRS=
